==> mythdvd_0.16.orig.tar.gz: mythdvd-0.16/i18n/mythdvd_sv.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>Förbindelsen till Myth omkodningsdemon har brutits. Inte bra.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Kan ej ansluta till Myth omkodningsdemon. Du kan försöka med att trycka på godtycklig siffertangent för att starta den. Om du ser detta meddelande är något fel.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Kunde ej slå upp datornamnet för din omkodningsserver. Inte bra.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Kommunikationsfel (eng: Socket communication errors). Inte bra.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Något är fel men jag vet inte riktigt vad.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Jobb %1 av %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Inga kopieringsjobb och inget annat att göra. Tryck 0 för att kopiera en DVD.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Inga jobb. Kontrollerar/väntar på DVDn.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Inga jobb och inget annat att göra. Du kan trycka 0 för att kopiera en DVD.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Avbryter ...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Ny kopiering</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Avbryt jobb</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

Du har inget VCD-uppspelningskommando definierat.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>OK, kör Inställningar</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

Du har ingen VCD-enhet definierad.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

Du har inget DVD-avspelningskommando definierat.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

Du har ingen DVD-enhet definierad.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>VCD-enhet</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Denna enhet måste existera och användaren som kör MythDVD måste ha läsrättigheter på den.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>DVD-enhet</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Generella inställningar</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Kommando för DVD-avspelning</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Detta är ett godtyckligt kommando för att starta en DVD-spelare (t ex MPlayer, ogle etc). Om tecknen &apos;%d&apos; ingår i kommandot kommer detta att ersättas med den konfigurerade DVD-enheten (t ex /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Kommando för VCD-avspelning</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Detta är ett godtyckligt kommando för att starta en VCD-spelare (t ex MPlayer, xine etc). Om tecknen &apos;%d&apos; ingår i kommandot kommer detta att ersättas med den konfigurerade VCD-enheten (t ex /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Inställningar för DVD-avspelning</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Inställningar för VCD-avspelning</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Bibliotek för temporära filer</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Detta bibliotek måste existera och användaren som kör MythDVD måste ha skrivrättigheter till det.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Titelavspeningskommando</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Detta kommando används för att spela upp en förhandsvisning för en given DVD-titel. Följande teckensekvenser, som ersätts i det slutliga kommandot, kan användas: %d för enhet, %a för ljudspår, %c för ljudkanaler.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Textningsargument:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Om du väljer textning vid kopiering kommer dessa kommandoradsargument att läggas till på slutet av Titelavspelningskommandot. Om teckensekvensen %s anges kommer denna att ersättas med textningsspårets namn i det slutliga kommandot.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Baskommando för omkodning</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Detta är baskommandot (utan kommandoradsargument) för att köra omkodning på ditt system.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>Portnummer för omkodningsdemon</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Detta är TCP-portnumret som skall användas för att kommunicera med omkodningsdemonen</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Omkodningsdemonen loggar till terminalfönstret</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Om denna funktion aktiveras kommer omkodningsdemonen (eng: Myth Transconding Daemon) att logga till det teminalfönster den startades från. Om funktionen inte är aktiverad kommer loggningen att ske till filen mtd.log.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Använd AC3-ljud</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Om denna funktion är aktiverad kommer omkodningsdemonen (eng: Myth Transcoding Daemon) att bevara AC3-ljud (Dolby Digital) i omkodade filer.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Använd xvid i stället för divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Om funktionen är aktiverad kommer MythDVD att använda den fria kodnings/avkodnings-mjukvaran xvid i stället för divx närhelst det är möjligt.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Prioritet för omkodning</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Denna inställning justerar prioriteten för omkodningsdemonen (eng: Myth Transcoding Daemon). Värdet kan sägas vara en omvänd prioritet där högre värden (max 20) ger lägre prioritet och lägre värden (min -20) ger högre prioritet. Ett värde större än 0 är ofta bra för att inte störa andra processer.</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Segmentstorlek för kopierad video</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Om detta värde är satt till något annat än 0 kommer kopierade videospår att delas upp i filer med motsvarande storlek (i MB). Inställningen gäller för både inspelningar av perfekt kvalitet och mellanfiler som används vid omkodning.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>DVD-kopieringsinställningar</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>Inställningar för omkodningsdemon</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Väntar på tillgång till DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Kopierar till fil ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Perfekt DVD-kopiering av %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Omkodning av %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Väntar på tillstånd att börja omkodning</translation>
    </message>
    <message>
        <source>EMT: </source>
        <translation type="obsolete">EMT:</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Omkodar pass 1 av 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Omkodar pass 2 av 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Omkodar ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Omkodningsprocessen tänker</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Antal samtida omkodningsjobb</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Bestämmer hur många omkodningsprocesser som kan vara igång samtidigt. Från början är denna 1 vilket ger att endast en omkodning kan göras i taget.</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Kopiering/Omkodning</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Jobb 1 av 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Längd:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Välj:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvalitet:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Ljudspår:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3-ljud:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Textning:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Vy:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Titel 1 av 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Titel %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfekt</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Titel %1 av %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Processa vald titel</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Processa valda titlar</translation>
    </message>
</context>
</TS>

==> mythdvd_0.17.orig.tar.gz: mythdvd-0.17/i18n/mythdvd_sv.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>Förbindelsen till Myth omkodningsdemon har brutits. Inte bra.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Kan ej ansluta till Myth omkodningsdemon. Du kan försöka med att trycka på godtycklig siffertangent för att starta den. Om du ser detta meddelande är något fel.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Kunde ej slå upp datornamnet för din omkodningsserver. Inte bra.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Kommunikationsfel (eng: Socket communication errors). Inte bra.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Något är fel men jag vet inte riktigt vad.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Jobb %1 av %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Inga kopieringsjobb och inget annat att göra. Tryck 0 för att kopiera en DVD.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Inga jobb. Kontrollerar/väntar på DVDn.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Inga jobb och inget annat att göra. Du kan trycka 0 för att kopiera en DVD.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Avbryter ...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Ny kopiering</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Avbryt jobb</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

Du har inget VCD-uppspelningskommando definierat.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>OK, kör Inställningar</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

Du har ingen VCD-enhet definierad.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

Du har inget DVD-avspelningskommando definierat.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

Du har ingen DVD-enhet definierad.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>VCD-enhet</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Denna enhet måste existera och användaren som kör MythDVD måste ha läsrättigheter på den.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>DVD-enhet</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Generella inställningar</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Kommando för DVD-avspelning</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Detta är ett godtyckligt kommando för att starta en DVD-spelare (t ex MPlayer, ogle etc). Om tecknen &apos;%d&apos; ingår i kommandot kommer detta att ersättas med den konfigurerade DVD-enheten (t ex /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Kommando för VCD-avspelning</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Detta är ett godtyckligt kommando för att starta en VCD-spelare (t ex MPlayer, xine etc). Om tecknen &apos;%d&apos; ingår i kommandot kommer detta att ersättas med den konfigurerade VCD-enheten (t ex /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Inställningar för DVD-avspelning</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Inställningar för VCD-avspelning</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Bibliotek för temporära filer</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Detta bibliotek måste existera och användaren som kör MythDVD måste ha skrivrättigheter till det.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Titelavspeningskommando</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Detta kommando används för att spela upp en förhandsvisning för en given DVD-titel. Följande teckensekvenser, som ersätts i det slutliga kommandot, kan användas: %d för enhet, %a för ljudspår, %c för ljudkanaler.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Textningsargument:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Om du väljer textning vid kopiering kommer dessa kommandoradsargument att läggas till på slutet av Titelavspelningskommandot. Om teckensekvensen %s anges kommer denna att ersättas med textningsspårets namn i det slutliga kommandot.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Baskommando för omkodning</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Detta är baskommandot (utan kommandoradsargument) för att köra omkodning på ditt system.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>Portnummer för omkodningsdemon</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Detta är TCP-portnumret som skall användas för att kommunicera med omkodningsdemonen</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Omkodningsdemonen loggar till terminalfönstret</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Om denna funktion aktiveras kommer omkodningsdemonen (eng: Myth Transconding Daemon) att logga till det teminalfönster den startades från. Om funktionen inte är aktiverad kommer loggningen att ske till filen mtd.log.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Använd AC3-ljud</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Om denna funktion är aktiverad kommer omkodningsdemonen (eng: Myth Transcoding Daemon) att bevara AC3-ljud (Dolby Digital) i omkodade filer.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Använd xvid i stället för divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Om funktionen är aktiverad kommer MythDVD att använda den fria kodnings/avkodnings-mjukvaran xvid i stället för divx närhelst det är möjligt.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Prioritet för omkodning</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Denna inställning justerar prioriteten för omkodningsdemonen (eng: Myth Transcoding Daemon). Värdet kan sägas vara en omvänd prioritet där högre värden (max 20) ger lägre prioritet och lägre värden (min -20) ger högre prioritet. Ett värde större än 0 är ofta bra för att inte störa andra processer.</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Segmentstorlek för kopierad video</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Om detta värde är satt till något annat än 0 kommer kopierade videospår att delas upp i filer med motsvarande storlek (i MB). Inställningen gäller för både inspelningar av perfekt kvalitet och mellanfiler som används vid omkodning.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>DVD-kopieringsinställningar</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>Inställningar för omkodningsdemon</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Väntar på tillgång till DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Kopierar till fil ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Perfekt DVD-kopiering av %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Omkodning av %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Väntar på tillstånd att börja omkodning</translation>
    </message>
    <message>
        <source>EMT: </source>
        <translation type="obsolete">EMT:</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Omkodar pass 1 av 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Omkodar pass 2 av 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Omkodar ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Omkodningsprocessen tänker</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Antal samtida omkodningsjobb</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Bestämmer hur många omkodningsprocesser som kan vara igång samtidigt. Från början är denna 1 vilket ger att endast en omkodning kan göras i taget.</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation>Vid iläggning av DVD</translation>
    </message>
    <message>
        <source>Display mythdvd menu menu</source>
        <translation type="obsolete">Visa MythDVD-meny</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Gör ingenting</translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation>Spela DVD</translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation>Kopiera DVD</translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation>Mediaövervakning måste aktiveras för att tillåta denna funktion.</translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation>Visa MythDVD-menyn</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Kopiering/Omkodning</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Jobb 1 av 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Längd:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Välj:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvalitet:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Ljudspår:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3-ljud:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Textning:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Vy:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Titel 1 av 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation>0:00:00</translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Titel %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfekt</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Titel %1 av %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Processa vald titel</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Processa valda titlar</translation>
    </message>
</context>
</TS>
